;*****************************************************************************
;
; wnaspi32.inc (Include file for ASPI for Win32.)
;
; Original file: wnaspi32.h (from Adaptec's ASPISDK) 
;
;*****************************************************************************
 
;*****************************************************************************
;      %%% SCSI MISCELLANEOUS EQUATES %%%
;*****************************************************************************
 
SENSE_LEN                   equ  14	;Default sense buffer length
SRB_DIR_SCSI                equ  00h	;Direction determined by SCSI
SRB_POSTING                 equ  01h	;Enable ASPI posting
SRB_ENABLE_RESIDUAL_COUNT   equ  04h	;Enable residual byte count reporting
SRB_DIR_IN                  equ  08h	;Transfer from SCSI target to host
SRB_DIR_OUT                 equ  10h	;Transfer from host to SCSI target
SRB_EVENT_NOTIFY            equ  40h	;Enable ASPI event notification

RESIDUAL_COUNT_SUPPORTED    equ  02h	;Extended buffer flag
MAX_SRB_TIMEOUT             equ  108000	;30 hour maximum timeout in s
DEFAULT_SRB_TIMEOUT         equ  108000	;Max timeout by default
 
;*****************************************************************************
;      %%% ASPI Command Definitions %%%
;*****************************************************************************
 
SC_HA_INQUIRY               equ  00h	;Host adapter inquiry
SC_GET_DEV_TYPE             equ  01h	;Get device type
SC_EXEC_SCSI_CMD            equ  02h	;Execute SCSI command
SC_ABORT_SRB                equ  03h	;Abort an SRB
SC_RESET_DEV                equ  04h	;SCSI bus device reset
SC_SET_HA_PARMS             equ  05h	;Set HA parameters
SC_GET_DISK_INFO            equ  06h	;Get Disk information
SC_RESCAN_SCSI_BUS          equ  07h	;ReBuild SCSI device map
SC_GETSET_TIMEOUTS          equ  08h	;Get/Set target timeouts
 
;*****************************************************************************
;      %%% SRB Status %%%
;*****************************************************************************
 
SS_PENDING                  equ  00h	;SRB being processed
SS_COMP                     equ  01h	;SRB completed without error
SS_ABORTED                  equ  02h	;SRB aborted
SS_ABORT_FAIL               equ  03h	;Unable to abort SRB
SS_ERR                      equ  04h	;SRB completed with error

SS_INVALID_CMD              equ  80h	;Invalid ASPI command
SS_INVALID_HA               equ  81h	;Invalid host adapter number
SS_NO_DEVICE                equ  82h	;SCSI device not installed

SS_INVALID_SRB              equ 0e0h	;Invalid parameter set in SRB
SS_OLD_MANAGER              equ 0e1h	;ASPI manager doesn't support Windows
SS_BUFFER_ALIGN             equ 0e1h	;Buffer not aligned (replaces OLD_MANAGER in Win32)
SS_ILLEGAL_MODE             equ 0e2h	;Unsupported Windows mode
SS_NO_ASPI                  equ 0e3h	;No ASPI managers resident
SS_FAILED_INIT              equ 0e4h	;ASPI for windows failed init
SS_ASPI_IS_BUSY             equ 0e5h	;No resources available to execute cmd
SS_BUFFER_TO_BIG            equ 0e6h	;Buffer size to big to handle!
SS_MISMATCHED_COMPONENTS    equ 0e7h	;The DLLs/EXEs of ASPI don't version check
SS_NO_ADAPTERS              equ 0e8h	;No host adapters to manage
SS_INSUFFICIENT_RESOURCES   equ 0e9h	;Couldn't allocate resources needed to init
SS_ASPI_IS_SHUTDOWN         equ 0eah	;Call came to ASPI after PROCESS_DETACH
SS_BAD_INSTALL              equ 0ebh	;The DLL or other components are installed wrong
 
;*****************************************************************************
;      %%% Host Adapter Status %%%
;*****************************************************************************
 
HASTAT_OK                   equ  00h	;Host adapter did not detect an
HASTAT_SEL_TO               equ  11h	;Selection Timeout
HASTAT_DO_DU                equ  12h	;Data overrun data underrun
HASTAT_BUS_FREE             equ  13h	;Unexpected bus free
HASTAT_PHASE_ERR            equ  14h	;Target bus phase sequence failure
HASTAT_TIMEOUT              equ  09h	;Timed out while SRB was
HASTAT_COMMAND_TIMEOUT      equ  0bh	;Adapter timed out processing SRB.
HASTAT_MESSAGE_REJECT       equ  0dh	;While processing SRB, the
HASTAT_BUS_RESET            equ  0eh	;A bus reset was detected.
HASTAT_PARITY_ERROR         equ  0fh	;A parity error was detected.
HASTAT_REQUEST_SENSE_FAILED equ  10h	;The adapter failed in issuing
 
;*****************************************************************************
;          %%% SRB - HOST ADAPTER INQUIRY - SC_HA_INQUIRY (0) %%%
;*****************************************************************************
                                        ;Offset 
SRB_HAInquiry struct                    ;HX/DEC
    SRB_Cmd              db ?           ;00/000 ASPI command code = SC_HA_INQUIRY
    SRB_Status           db ?           ;01/001 ASPI command status byte
    SRB_HaId             db ?           ;02/002 ASPI host adapter number
    SRB_Flags            db ?           ;03/003 ASPI request flags
    SRB_Hdr_Rsvd         dd ?           ;04/004 Reserved, MUST = 0
    HA_Count             db ?           ;08/008 Number of host adapters present
    HA_SCSI_ID           db ?           ;09/009 SCSI ID of host adapter
    HA_ManagerId         db 16 dup (?)  ;0A/010 String describing the manager
    HA_Identifier        db 16 dup (?)  ;1A/026 String describing the host adapter
    HA_Unique            db 16 dup (?)  ;2A/042 Host Adapter Unique parameters
    HA_Rsvd1             dw ?           ;3A/058 Reserved, MUST = 0
SRB_HAInquiry ends
 
;*****************************************************************************
;          %%% SRB - GET DEVICE TYPE - SC_GET_DEV_TYPE (1) %%%
;*****************************************************************************
                                        ;Offset
SRB_GDEVBlock struct                    ;HX/DEC
    SRB_Cmd              db ?           ;00/000 ASPI command code = SC_GET_DEV_TYPE
    SRB_Status           db ?           ;01/001 ASPI command status byte
    SRB_HaId             db ?           ;02/002 ASPI host adapter number
    SRB_Flags            db ?           ;03/003 Reserved, MUST = 0
    SRB_Hdr_Rsvd         dd ?           ;04/004 Reserved, MUST = 0
    SRB_Target           db ?           ;08/008 Target's SCSI ID
    SRB_Lun              db ?           ;09/009 Target's LUN number
    SRB_DeviceType       db ?           ;0A/010 Target's peripheral device type
    SRB_Rsvd1            db ?           ;0B/011 Reserved, MUST = 0
SRB_GDEVBlock ends
 
;*****************************************************************************
;          %%% SRB - EXECUTE SCSI COMMAND - SC_EXEC_SCSI_CMD (2) %%%
;*****************************************************************************
                                        ;Offset
SRB_ExecSCSICmd struct                  ;HX/DEC
    SRB_Cmd              db ?           ;00/000 ASPI command code = SC_EXEC_SCSI_CMD
    SRB_Status           db ?           ;01/001 ASPI command status byte
    SRB_HaId             db ?           ;02/002 ASPI host adapter number
    SRB_Flags            db ?           ;03/003 ASPI request flags
    SRB_Hdr_Rsvd         dd ?           ;04/004 Reserved
    SRB_Target           db ?           ;08/008 Target's SCSI ID
    SRB_Lun              db ?           ;09/009 Target's LUN number
    SRB_Rsvd1            dw ?           ;0A/010 Reserved for Alignment
    SRB_BufLen           dd ?           ;0C/012 Data Allocation Length
    SRB_BufPointer       dd ?           ;10/016 Data Buffer Pointer
    SRB_SenseLen         db ?           ;14/020 Sense Allocation Length
    SRB_CDBLen           db ?           ;15/021 CDB Length
    SRB_HaStat           db ?           ;16/022 Host Adapter Status
    SRB_TargStat         db ?           ;17/023 Target Status
    SRB_PostProc         dd ?           ;18/024 Post routine
    SRB_Rsvd2            db 20 dup (?)  ;1C/028 Reserved, MUST = 0
    CDBByte              db 16 dup (?)  ;30/048 SCSI CDB
    SenseArea            db 16 dup (?)  ;50/064 Request Sense buffer (14+2)
SRB_ExecSCSICmd ends
 
;*****************************************************************************
;          %%% SRB - ABORT AN SRB - SC_ABORT_SRB (3) %%%
;*****************************************************************************
                                        ;Offset
SRB_Abort struct                        ;HX/DEC
    SRB_Cmd              db ?           ;00/000 ASPI command code = SC_ABORT_SRB
    SRB_Status           db ?           ;01/001 ASPI command status byte
    SRB_HaId             db ?           ;02/002 ASPI host adapter number
    SRB_Flags            db ?           ;03/003 Reserved
    SRB_Hdr_Rsvd         dd ?           ;04/004 Reserved
    SRB_ToAbort          dd ?           ;08/008 Pointer to SRB to abort
SRB_Abort ends
 
;*****************************************************************************
;          %%% SRB - BUS DEVICE RESET - SC_RESET_DEV (4) %%%
;*****************************************************************************
                                        ;Offset 
SRB_BusDeviceReset struct               ;HX/DEC
    SRB_Cmd              db ?           ;00/000 ASPI command code = SC_RESET_DEV
    SRB_Status           db ?           ;01/001 ASPI command status byte
    SRB_HaId             db ?           ;02/002 ASPI host adapter number
    SRB_Flags            db ?           ;03/003 ASPI request flags
    SRB_Hdr_Rsvd         dd ?           ;04/004 Reserved
    SRB_Target           db ?           ;08/008 Target's SCSI ID
    SRB_Lun              db ?           ;09/009 Target's LUN number
    SRB_Rsvd1            db 12 dup (?)  ;0A/010 Reserved for Alignment
    SRB_HaStat           db ?           ;16/022 Host Adapter Status
    SRB_TargStat         db ?           ;17/023 Target Status
    SRB_PostProc         dd ?           ;18/024 Post routine
    SRB_Rsvd2            db 36 dup (?)  ;1C/028 Reserved, MUST = 0
SRB_BusDeviceReset ends
 
;*****************************************************************************
;          %%% SRB - GET DISK INFORMATION - SC_GET_DISK_INFO %%%
;*****************************************************************************
                                        ;Offset 
SRB_GetDiskInfo struct                  ;HX/DEC
    SRB_Cmd              db ?           ;00/000 ASPI command code = SC_GET_DISK_INFO
    SRB_Status           db ?           ;01/001 ASPI command status byte
    SRB_HaId             db ?           ;02/002 ASPI host adapter number
    SRB_Flags            db ?           ;03/003 Reserved, MUST = 0
    SRB_Hdr_Rsvd         dd ?           ;04/004 Reserved, MUST = 0
    SRB_Target           db ?           ;08/008 Target's SCSI ID
    SRB_Lun              db ?           ;09/009 Target's LUN number
    SRB_DriveFlags       db ?           ;0A/010 Driver flags
    SRB_Int13HDriveInfo  db ?           ;0B/011 Host Adapter Status
    SRB_Heads            db ?           ;0C/012 Preferred number of heads translation
    SRB_Sectors          db ?           ;0D/013 Preferred number of sectors translation
    SRB_Rsvd1            db 10 dup (?)  ;0E/014 Reserved, MUST = 0
SRB_GetDiskInfo ends
 
;*****************************************************************************
;          %%%  SRB - RESCAN SCSI BUS(ES) ON SCSIPORT %%%
;*****************************************************************************
                                        ;Offset 
SRB_RescanPort struct                   ;HX/DEC
    SRB_Cmd              db ?           ;00/000 ASPI command code = SC_RESCAN_SCSI_BUS
    SRB_Status           db ?           ;01/001 ASPI command status byte
    SRB_HaId             db ?           ;02/002 ASPI host adapter number
    SRB_Flags            db ?           ;03/003 Reserved, MUST = 0
    SRB_Hdr_Rsvd         dd ?           ;04/004 Reserved, MUST = 0
SRB_RescanPort ends
 
;*****************************************************************************
;          %%% SRB - GET/SET TARGET TIMEOUTS %%%
;*****************************************************************************
                                        ;Offset 
SRB_GetSetTimeouts struct               ;HX/DEC
    SRB_Cmd              db ?           ;00/000 ASPI command code = SC_GETSET_TIMEOUTS
    SRB_Status           db ?           ;01/001 ASPI command status byte
    SRB_HaId             db ?           ;02/002 ASPI host adapter number
    SRB_Flags            db ?           ;03/003 ASPI request flags
    SRB_Hdr_Rsvd         dd ?           ;04/004 Reserved, MUST = 0
    SRB_Target           db ?           ;08/008 Target's SCSI ID
    SRB_Lun              db ?           ;09/009 Target's LUN number
    SRB_Timeout          dd ?           ;0A/010 Timeout in half seconds
SRB_GetSetTimeouts ends
 
;*****************************************************************************
;          %%% ASPIBUFF - Structure For Controllng I/O Buffers %%%
;*****************************************************************************
                                        ;Offset 
ASPI32BUFF struct                       ;HX/DEC
    AB_BufPointer        dd ?           ;00/000 Pointer to first byte of the ASPI allocated buffer
    AB_BufLen            dd ?           ;04/004 Length in bytes of the buffer
    AB_ZeroFill          dd ?           ;08/008 Flag set to 1 if buffer should be zeroed
    AB_Reserved          dd ?           ;0C/012 Reserved
ASPI32BUFF ends
